@@ -38,7 +38,6 @@ from hypothesis.internal.cache import LRUReusedCache
 from hypothesis.internal.cathetus import cathetus
 from hypothesis.internal.charmap import as_general_categories
 from hypothesis.internal.compat import (
-    abc,
     ceil,
     floor,
     gcd,
@@ -724,14 +723,13 @@ def lists(
     # type: (...) -> SearchStrategy[List[Ex]]
     """Returns a list containing values drawn from elements with length in the
     interval [min_size, max_size] (no bounds in that direction if these are
-    None). If max_size is 0 then elements may be None and only the empty list
-    will be drawn.
+    None). If max_size is 0, only the empty list will be drawn.
 
-    If unique is True (or something that evaluates to True), we compare direct
+    If ``unique`` is True (or something that evaluates to True), we compare direct
     object equality, as if unique_by was ``lambda x: x``. This comparison only
     works for hashable types.
 
-    If unique_by is not None it must be a callable or tuple of callables
+    If ``unique_by`` is not None it must be a callable or tuple of callables
     returning a hashable type when given a value drawn from elements. The
     resulting list will satisfy the condition that for ``i`` != ``j``,
     ``unique_by(result[i])`` != ``unique_by(result[j])``.
@@ -905,10 +903,11 @@ def dictionaries(
     # type: (...) -> SearchStrategy[Dict[Ex, T]]
     # Describing the exact dict_class to Mypy drops the key and value types,
     # so we report Dict[K, V] instead of Mapping[Any, Any] for now.  Sorry!
-    """Generates dictionaries of type dict_class with keys drawn from the keys
-    argument and values drawn from the values argument.
+    """Generates dictionaries of type ``dict_class`` with keys drawn from the ``keys``
+    argument and values drawn from the ``values`` argument.
 
-    The size parameters have the same interpretation as for lists.
+    The size parameters have the same interpretation as for
+    :func:`~hypothesis.strategies.lists`.
 
     Examples from this strategy shrink by trying to remove keys from the
     generated dictionary, and by shrinking each generated key and value.
@@ -1044,7 +1043,7 @@ def text(
 ):
     # type: (...) -> SearchStrategy[Text]
     """Generates values of a unicode text type (unicode on python 2, str on
-    python 3) with values drawn from alphabet, which should be an iterable of
+    python 3) with values drawn from ``alphabet``, which should be an iterable of
     length one strings or a strategy generating such strings.
 
     The default alphabet strategy can generate the full unicode range but
@@ -1052,7 +1051,7 @@ def text(
     encoding.  You can use :func:`~hypothesis.strategies.characters` without
     arguments to find surrogate-related bugs such as :bpo:`34454`.
 
-    min_size and max_size have the usual interpretations.
+    ``min_size`` and ``max_size`` have the usual interpretations.
     Note that Python measures string length by counting codepoints: U+00C5
     ``Å`` is a single character, while U+0041 U+030A ``Å`` is two - the ``A``,
     and a combining ring above.
@@ -1071,28 +1070,24 @@ def text(
     elif isinstance(alphabet, SearchStrategy):
         char_strategy = alphabet
     else:
-        char_strategy = sampled_from(list(alphabet)) if alphabet else nothing()
-        if not isinstance(alphabet, abc.Sequence):
-            raise InvalidArgument(
-                "alphabet must be an ordered sequence, or tests may be "
-                "flaky and shrinking weaker, but a %r is not a type of "
-                "sequence." % (type(alphabet),)
-            )
         non_string = [c for c in alphabet if not isinstance(c, string_types)]
         if non_string:
             raise InvalidArgument(
                 "The following elements in alphabet are not unicode "
                 "strings:  %r" % (non_string,)
             )
-        not_one_char = [
-            c for c in alphabet if isinstance(c, string_types) and len(c) != 1
-        ]
+        not_one_char = [c for c in alphabet if len(c) != 1]
         if not_one_char:
             raise InvalidArgument(
                 "The following elements in alphabet are not of length "
                 "one, which leads to violation of size constraints:  %r"
                 % (not_one_char,)
             )
+        char_strategy = (
+            characters(whitelist_categories=(), whitelist_characters=alphabet)
+            if alphabet
+            else nothing()
+        )
     if (max_size == 0 or char_strategy.is_empty) and not min_size:
         return just(u"")
     return StringStrategy(lists(char_strategy, min_size=min_size, max_size=max_size))
@@ -1450,13 +1445,13 @@ def fractions(
     # type: (...) -> SearchStrategy[Fraction]
     """Returns a strategy which generates Fractions.
 
-    If min_value is not None then all generated values are no less than
-    min_value.  If max_value is not None then all generated values are no
-    greater than max_value.  min_value and max_value may be anything accepted
+    If ``min_value`` is not None then all generated values are no less than
+    ``min_value``.  If ``max_value`` is not None then all generated values are no
+    greater than ``max_value``.  ``min_value`` and ``max_value`` may be anything accepted
     by the :class:`~fractions.Fraction` constructor.
 
-    If max_denominator is not None then the denominator of any generated
-    values is no greater than max_denominator. Note that max_denominator must
+    If ``max_denominator`` is not None then the denominator of any generated
+    values is no greater than ``max_denominator``. Note that ``max_denominator`` must
     be None or a positive integer.
 
     Examples from this strategy shrink towards smaller denominators, then
@@ -2154,10 +2149,6 @@ def data():
     """This isn't really a normal strategy, but instead gives you an object
     which can be used to draw data interactively from other strategies.
 
-    It can only be used within :func:`@given <hypothesis.given>`, not
-    :func:`find() <hypothesis.find>`. This is because the lifetime
-    of the object cannot outlast the test body.
-
     See :ref:`the rest of the documentation <interactive-draw>` for more
     complete information.
 
